"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GuildCreate = void 0;
const Channel_1 = require("../../resources/Channel");
const Guild_1 = require("../../resources/Guild");
const Member_1 = require("../../resources/Member");
const Role_1 = require("../../resources/Role");
const VoiceState_1 = require("../../resources/VoiceState");
const Constants_1 = require("../../utils/Constants");
const v10_1 = require("discord-api-types/v10");
const Event_1 = require("./Event");
class GuildCreate extends Event_1.Event {
    async run(data) {
        const guild = new Guild_1.Guild({
            ...data,
            shard_id: this.shardId,
            client: this.client,
        });
        for (const voiceState of data.voice_states) {
            const resolved = new VoiceState_1.VoiceState({
                client: this.client,
                guild_id: guild.id,
                ...voiceState,
            }, guild);
            guild.voiceStates.set(voiceState.user_id, resolved);
        }
        for (const role of data.roles) {
            const resolved = new Role_1.Role({ ...role, client: this.client }, guild);
            guild.roles.add(resolved);
            this.client.roles.cache._add(resolved);
        }
        for (const channel of data.channels) {
            const resolved = Channel_1.Channel.from({ ...channel, client: this.client }, guild);
            guild.channels.add(resolved);
            this.client.channels.add(resolved);
        }
        for (const member of data.members) {
            const resolved = new Member_1.Member(member, guild);
            guild.members.add(resolved, true);
        }
        if (!this.gatewayShard.ready &&
            this.client.options.gateway.intents & v10_1.GatewayIntentBits.GuildMembers) {
            this.gatewayShard.requestGuildMembers({
                guildId: data.id,
                nonce: Date.now().toString() + Math.random().toString(36),
                query: "",
                limit: 0,
                userIds: undefined,
            });
        }
        // Add guild to global cache
        this.client.guilds.add(guild);
        if (this.client.websocket.allReady()) {
            this.client.emit(Constants_1.Events.GuildCreate, guild);
        }
        else if (this.gatewayShard.status === Constants_1.GatewayStatus.WaitingGuilds) {
            this.gatewayShard.pendingGuilds--;
            this.gatewayShard.pendingGuildsMap.delete(guild.id);
            if (this.gatewayShard.pendingGuilds === 0) {
                this.gatewayShard.ready = true;
                this.gatewayShard.status = Constants_1.GatewayStatus.Ready;
                this.client.websocket.fireClientReady();
            }
        }
    }
}
exports.GuildCreate = GuildCreate;
