"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThreadListSync = void 0;
const Channel_1 = require("../../resources/Channel");
const Event_1 = require("./Event");
const Channel_2 = require("../../resources/Channel");
const Member_1 = require("../../resources/Member");
const Constants_1 = require("../../utils/Constants");
const DataManager_1 = require("../../manager/DataManager");
class ThreadListSync extends Event_1.Event {
    run(data) {
        const guild = this.getGuild(data.guild_id);
        if (!guild)
            return;
        if (data.channel_ids) {
            for (const id of data.channel_ids) {
                const channel = this.client.channels.cache.get(id);
                if (channel instanceof Channel_1.GuildChannel) {
                    channel.threads.forEach((thread) => {
                        if (!thread.archived) {
                            channel.threads.delete(thread.id);
                        }
                    });
                }
            }
        }
        else {
            for (const channel of guild.channels.cache
                .filter((channel) => channel instanceof Channel_1.GuildChannel)
                .values()) {
                channel.threads.forEach((thread) => {
                    if (!thread.archived) {
                        channel.threads.delete(thread.id);
                    }
                });
            }
        }
        const threads = data.threads.reduce((cache, raw) => {
            const thread = new Channel_2.ThreadChannel({ ...raw, client: this.client }, guild);
            cache.set(thread.id, thread);
            return this.client.cache.threads.set(thread.id, thread);
        }, new DataManager_1.DataCache());
        for (const raw of data.members) {
            const thread = this.client.cache.threads.get(raw.id);
            if (thread) {
                const member = new Member_1.ThreadMember({ ...raw, client: this.client }, thread);
                thread.members._add(member);
                const channel = guild.channels.cache.get(thread.channel.id);
                if (channel instanceof Channel_1.GuildChannel) {
                    channel.threads._add(thread);
                }
            }
        }
        this.client.emit(Constants_1.Events.ThreadListSync, threads, guild);
    }
}
exports.ThreadListSync = ThreadListSync;
