"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GuildChannelDataManager = exports.ClientChannelsDataManager = exports.ChannelDataManager = void 0;
const Channel_1 = require("../resources/Channel");
const v10_1 = require("discord-api-types/v10");
const DataManager_1 = require("./DataManager");
const Resolvable_1 = require("../utils/Resolvable");
const Forgified_1 = require("../resources/forge/Forgified");
class ChannelDataManager extends DataManager_1.DataManager {
    manager;
    constructor(options, manager) {
        super(options, (get, id) => {
            const channel = get(id);
            return channel && this._resolve(channel);
        });
        this.manager = manager;
    }
    _resolve(channel, guild, addInCache = false) {
        if (
        // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
        channel &&
            !(channel instanceof Channel_1.Channel)) {
            if (channel?.guild_id &&
                !guild) {
                guild = this.manager.client.guilds.cache.get(channel.guild_id);
            }
            channel = Channel_1.Channel.from({
                ...channel,
                client: this.manager.client,
            }, guild);
            if (addInCache)
                this.add(channel);
        }
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        return channel;
    }
    add(channel, replace = true) {
        if (!channel || !channel.id) {
            return null;
        }
        return super.add(this._resolve(channel), replace, channel.id);
    }
    get(id) {
        return this.cache.get(id);
    }
    forge(data, guild) {
        let base = Channel_1.Channel;
        if (typeof data === "string") {
            data = { id: data };
        }
        if ("type" in data && data.type) {
            switch (data.type) {
                case v10_1.ChannelType.DM: {
                    base = Channel_1.DMChannel;
                    break;
                }
                case v10_1.ChannelType.GuildText: {
                    base = Channel_1.GuildTextChannel;
                    break;
                }
                case v10_1.ChannelType.GuildVoice: {
                    base = Channel_1.VoiceChannel;
                    break;
                }
                case v10_1.ChannelType.PublicThread:
                case v10_1.ChannelType.PrivateThread: {
                    base = Channel_1.ThreadChannel;
                    break;
                }
                case v10_1.ChannelType.GuildStageVoice: {
                    base = Channel_1.StageChannel;
                    break;
                }
                case v10_1.ChannelType.GuildCategory: {
                    base = Channel_1.CategoryChannel;
                    break;
                }
                case v10_1.ChannelType.GuildForum: {
                    base = Channel_1.ForumChannel;
                    break;
                }
                default: {
                    base = Channel_1.Channel;
                    break;
                }
            }
        }
        return this.add(new Forgified_1.Forge(this.manager.client, base).forge(...[data, guild]), false);
    }
    async fetch(id) {
        const item = await this.manager.client.rest.getChannel(id);
        let guild;
        if ("guild_id" in item && item.guild_id) {
            guild = this.manager.client.guilds.cache.get(item.guild_id);
        }
        const i = Channel_1.Channel.from({
            ...item,
            client: this.manager.client,
        }, guild);
        return this.add(i);
    }
}
exports.ChannelDataManager = ChannelDataManager;
class ClientChannelsDataManager extends ChannelDataManager {
    _add(channel, guild, replace = true) {
        return super.add(super._resolve(channel, guild ? Resolvable_1.Resolvable.resolveGuild(guild, this.manager.client) : undefined), replace);
    }
}
exports.ClientChannelsDataManager = ClientChannelsDataManager;
class GuildChannelDataManager extends ChannelDataManager {
    guild;
    constructor(options, manager, guild) {
        super(options, manager);
        this.guild = guild;
    }
    add(channel, replace = true) {
        return super.add(super._resolve(channel, this.guild), replace);
    }
}
exports.GuildChannelDataManager = GuildChannelDataManager;
