"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GuildEmojiDataManager = exports.EmojiDataManager = void 0;
const Emoji_1 = require("../resources/Emoji");
const DataManager_1 = require("./DataManager");
const Forgified_1 = require("../resources/forge/Forgified");
class EmojiDataManager extends DataManager_1.DataManager {
    manager;
    constructor(options, manager) {
        super(options, (get, id) => {
            const emoji = get(id);
            return emoji && this.#resolve(emoji);
        });
        this.manager = manager;
    }
    get(id) {
        return this.cache.get(id);
    }
    #resolve(emoji, addInCache = false) {
        if (emoji && !(emoji instanceof Emoji_1.Emoji)) {
            emoji = new Emoji_1.Emoji(emoji);
        }
        if (addInCache)
            this.add(emoji);
        return emoji;
    }
    add(emoji, replace = true) {
        return super.add(this.#resolve(emoji), replace, emoji.id || emoji.name);
    }
    forge(data) {
        if (typeof data !== "string" && !data.id && !data.name) {
            throw new Error("Emoji id or name is required to be forged");
        }
        const forged = new Forgified_1.Forge(this.manager.client, Emoji_1.Emoji).forge(typeof data === "string" ? { id: data } : data);
        return this.add(forged, false);
    }
    /**
     *
     * @param id emoji id
     * @param guild Guild object or Guild Id
     */
    async fetch(id, guild) {
        const emoji = await this.manager.client.rest.getEmoji(typeof guild === "string" ? guild : guild.id, id);
        return this.add(emoji);
    }
}
exports.EmojiDataManager = EmojiDataManager;
class GuildEmojiDataManager extends EmojiDataManager {
    manager;
    guild;
    constructor(options, manager, guild) {
        super(options, manager);
        this.manager = manager;
        this.guild = guild;
    }
    fetch(id) {
        return super.fetch(id, this.guild);
    }
}
exports.GuildEmojiDataManager = GuildEmojiDataManager;
