"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageDataManager = void 0;
const Message_1 = require("../resources/Message");
const Resolvable_1 = require("../utils/Resolvable");
const DataManager_1 = require("./DataManager");
const Forgified_1 = require("../resources/forge/Forgified");
class MessageDataManager extends DataManager_1.DataManager {
    manager;
    channel;
    constructor(options, manager, channel) {
        super(options, (get, id) => {
            let message = get(id);
            if (!message)
                return;
            if (!(message instanceof Message_1.Message)) {
                const guild = "guild" in this.channel
                    ? // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                        // @ts-ignore
                        this.channel.guild
                    : undefined;
                message = new Message_1.Message({
                    ...message,
                    client: this.manager.client,
                }, guild);
            }
            return Resolvable_1.Resolvable.resolveMessage(message, this.manager.client);
        });
        this.manager = manager;
        this.channel = channel;
    }
    get(id) {
        return this.cache.get(id);
    }
    forge(data) {
        const forged = new Forgified_1.Forge(this.manager.client, Message_1.Message).forge(typeof data === "string" ? { id: data } : data);
        return this.add(forged, false);
    }
    async fetch(options) {
        if (typeof options === "string") {
            const message = (await this.manager.client.rest.getMessage(this.channel.id, options));
            return Resolvable_1.Resolvable.resolveMessage(new Message_1.Message({
                ...message,
                client: this.manager.client,
            }), this.manager.client);
        }
        const messageArr = (await this.manager.client.rest.getMessages(this.channel.id, options));
        return Promise.all(messageArr.map((message_1) => Resolvable_1.Resolvable.resolveMessage(new Message_1.Message({
            ...message_1,
            client: this.manager.client,
        }), this.manager.client)));
    }
}
exports.MessageDataManager = MessageDataManager;
