"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Forge = exports.ForgifiedAPI = exports.ForgifiedAPIError = void 0;
const Member_1 = require("../Member");
const Guild_1 = require("../Guild");
const User_1 = require("../User");
const Emoji_1 = require("../Emoji");
const Message_1 = require("../Message");
const Channel_1 = require("../Channel");
const CAN_BE_FORGED_LIST = [
    "Message",
    "Guild",
    "User",
    "Member",
    "Channel",
    "Emoji",
    "Reaction",
    "Application",
    "ForumChannel",
    "GuildChannel",
    "TextBasedChannel",
    "GuildTextChannel",
    "StageChannel",
    "VoiceChannel",
    "DMChannel",
    "BaseVoiceChannel",
    "CategoryChannel",
    "ThreadChannel",
    "WelcomeChannel",
    "CategoryChannel",
    "ForumChannel",
    "StageChannel",
    "Role",
];
class ForgifiedAPIError extends Error {
    constructor(message) {
        super(message);
        this.name = "ForgifiedAPIError";
    }
}
exports.ForgifiedAPIError = ForgifiedAPIError;
var ForgifiedAPI;
(function (ForgifiedAPI) {
    ForgifiedAPI.Error = ForgifiedAPIError;
    function CAN_BE_FORGED(x) {
        return CAN_BE_FORGED_LIST.includes(x.name);
    }
    ForgifiedAPI.CAN_BE_FORGED = CAN_BE_FORGED;
    ForgifiedAPI.FORGIFIED = Symbol("ForgifiedAPI");
})(ForgifiedAPI = exports.ForgifiedAPI || (exports.ForgifiedAPI = {}));
class Forge {
    client;
    base;
    constructor(client, base) {
        this.client = client;
        this.base = base;
        if (!ForgifiedAPI.CAN_BE_FORGED(base)) {
            throw new ForgifiedAPIError(`Cannot forge ${base.name}, incompatible class`);
        }
    }
    // @ts-expect-error - params is valid array
    forge(...params) {
        // @ts-expect-error - params is valid
        const data = new this.base(...params);
        Object.defineProperty(data, "_client", {
            value: this.client,
        });
        Object.defineProperty(data, "isForged", {
            value: true,
            writable: false,
        });
        Object.defineProperty(data, ForgifiedAPI.FORGIFIED, {
            value: `Forgified<${this.base.name}>`,
            writable: false,
        });
        if (data instanceof Channel_1.Channel || data instanceof Channel_1.GuildTextChannel) {
            this.client.channels.cache._add(data, false, data.id);
        }
        else if (data instanceof Guild_1.Guild) {
            this.client.guilds.cache._add(data, false, data.id);
        }
        else if (data instanceof User_1.User) {
            this.client.users.cache._add(data, false, data.id);
        }
        else if (data instanceof Member_1.Member) {
            (params[1] instanceof Guild_1.Guild
                ? params[1]
                : this.client.guilds.cache.get(data.guild?.id))?.members.add(data, false);
        }
        else if (data instanceof Message_1.Message) {
            const channel = this.client.channels.cache.get(data.channelId);
            if (channel && channel.isText()) {
                channel.messages.add(data, false);
            }
        }
        else if (data instanceof Emoji_1.Reaction) {
            let message = data.message;
            if (!message && data.channelId && data.messageId) {
                const channel = this.client.channels.cache.get(data.channelId);
                if (channel && channel.isText()) {
                    message = channel.messages.cache.get(data.messageId) ?? null;
                }
            }
            if (message) {
                message.reactions._add(data, false, data.emoji.id ?? data.emoji.name);
            }
        }
        return data;
    }
}
exports.Forge = Forge;
