"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventSource = void 0;
const index_1 = require("../../utils/index");
const channelCreate_1 = require("./events/channelCreate");
const channelDelete_1 = require("./events/channelDelete");
const channelPinsUpdate_1 = require("./events/channelPinsUpdate");
const channelUpdate_1 = require("./events/channelUpdate");
const guildAuditLogEntryCreate_1 = require("./events/guildAuditLogEntryCreate");
const guildBanAdd_1 = require("./events/guildBanAdd");
const guildBanRemove_1 = require("./events/guildBanRemove");
const guildCreate_1 = require("./events/guildCreate");
const guildDelete_1 = require("./events/guildDelete");
const guildEmojisUpdate_1 = require("./events/guildEmojisUpdate");
const guildIntegrationsUpdate_1 = require("./events/guildIntegrationsUpdate");
const guildMemberAdd_1 = require("./events/guildMemberAdd");
const guildMemberRemove_1 = require("./events/guildMemberRemove");
const guildMembersChunk_1 = require("./events/guildMembersChunk");
const guildMemberUpdate_1 = require("./events/guildMemberUpdate");
const guildRoleCreate_1 = require("./events/guildRoleCreate");
const guildRoleDelete_1 = require("./events/guildRoleDelete");
const guildRoleUpdate_1 = require("./events/guildRoleUpdate");
const guildScheduledEventCreate_1 = require("./events/guildScheduledEventCreate");
const guildScheduledEventDelete_1 = require("./events/guildScheduledEventDelete");
const guildScheduledEventUpdate_1 = require("./events/guildScheduledEventUpdate");
const guildScheduledEventUserAdd_1 = require("./events/guildScheduledEventUserAdd");
const guildScheduledEventUserRemove_1 = require("./events/guildScheduledEventUserRemove");
const guildStickersUpdate_1 = require("./events/guildStickersUpdate");
const guildUpdate_1 = require("./events/guildUpdate");
const integrationCreate_1 = require("./events/integrationCreate");
const interactionCreate_1 = require("./events/interactionCreate");
const inviteCreate_1 = require("./events/inviteCreate");
const inviteDelete_1 = require("./events/inviteDelete");
const messageCreate_1 = require("./events/messageCreate");
const messageDelete_1 = require("./events/messageDelete");
const messageDeleteBulk_1 = require("./events/messageDeleteBulk");
const messageReactionAdd_1 = require("./events/messageReactionAdd");
const messageReactionRemove_1 = require("./events/messageReactionRemove");
const messageReactionRemoveAll_1 = require("./events/messageReactionRemoveAll");
const messageReactionRemoveEmoji_1 = require("./events/messageReactionRemoveEmoji");
const messageUpdate_1 = require("./events/messageUpdate");
const ready_1 = require("./events/ready");
const stageInstanceCreate_1 = require("./events/stageInstanceCreate");
const stageInstanceDelete_1 = require("./events/stageInstanceDelete");
const stageInstanceUpdate_1 = require("./events/stageInstanceUpdate");
const threadCreate_1 = require("./events/threadCreate");
const threadDelete_1 = require("./events/threadDelete");
const threadListSync_1 = require("./events/threadListSync");
const threadMembersUpdate_1 = require("./events/threadMembersUpdate");
const threadMemberUpdate_1 = require("./events/threadMemberUpdate");
const typingStart_1 = require("./events/typingStart");
const userUpdate_1 = require("./events/userUpdate");
const voiceServerUpdate_1 = require("./events/voiceServerUpdate");
const voiceStateUpdate_1 = require("./events/voiceStateUpdate");
class EventSource {
  events;
  gatewayShard;
  constructor() {
    this.events = new Map();
  }
  _init() {
    // Gateway
    this.add(ready_1.Ready);
    // Interaction
    this.add(interactionCreate_1.InteractionCreate);
    // Guild
    this.add(guildCreate_1.GuildCreate);
    this.add(guildMembersChunk_1.GuildMembersChunk);
    this.add(guildUpdate_1.GuildUpdate);
    this.add(guildDelete_1.GuildDelete);
    this.add(guildAuditLogEntryCreate_1.GuildAuditLogEntryCreate);
    this.add(guildBanAdd_1.GuildBanAdd);
    this.add(guildBanRemove_1.GuildBanRemove);
    this.add(guildEmojisUpdate_1.GuildEmojisUpdate);
    this.add(guildStickersUpdate_1.GuildStickersUpdate);
    this.add(guildMemberAdd_1.GuildMemberAdd);
    this.add(guildMemberRemove_1.GuildMemberRemove);
    this.add(guildMemberUpdate_1.GuildMemberUpdate);
    this.add(guildIntegrationsUpdate_1.GuildIntegrationsUpdate);
    this.add(guildRoleCreate_1.GuildRoleCreate);
    this.add(guildRoleUpdate_1.GuildRoleUpdate);
    this.add(guildRoleDelete_1.GuildRoleDelete);
    this.add(guildScheduledEventCreate_1.GuildScheduledEventCreate);
    this.add(guildScheduledEventDelete_1.GuildScheduledEventDelete);
    this.add(guildScheduledEventUpdate_1.GuildScheduledEventUpdate);
    this.add(guildScheduledEventUserAdd_1.GuildScheduledEventUserAdd);
    this.add(guildScheduledEventUserRemove_1.GuildScheduledEventUserRemove);
    // Message
    this.add(messageCreate_1.MessageCreate);
    this.add(messageUpdate_1.MessageUpdate);
    this.add(messageDelete_1.MessageDelete);
    this.add(messageDeleteBulk_1.MessageDeleteBulk);
    this.add(messageReactionRemove_1.MessageReactionRemove);
    this.add(messageReactionRemoveAll_1.MessageReactionRemoveAll);
    this.add(messageReactionRemoveEmoji_1.MessageReactionRemoveEmoji);
    this.add(messageReactionAdd_1.MessageReactionAdd);
    this.add(typingStart_1.TypingStart);
    // Stage
    this.add(stageInstanceCreate_1.StageInstanceCreate);
    this.add(stageInstanceDelete_1.StageInstanceDelete);
    this.add(stageInstanceUpdate_1.StageInstanceUpdate);
    // Thread
    this.add(threadMemberUpdate_1.ThreadMemberUpdate);
    this.add(threadCreate_1.ThreadCreate);
    this.add(threadMembersUpdate_1.ThreadMembersUpdate);
    this.add(threadDelete_1.ThreadDelete);
    this.add(threadListSync_1.ThreadListSync);
    // Channel
    this.add(channelCreate_1.ChannelCreate);
    this.add(channelDelete_1.ChannelDelete);
    this.add(channelUpdate_1.ChannelUpdate);
    this.add(channelPinsUpdate_1.ChannelPinsUpdate);
    // User
    this.add(userUpdate_1.UserUpdate);
    // Voice
    this.add(voiceStateUpdate_1.VoiceStateUpdate);
    this.add(voiceServerUpdate_1.VoiceServerUpdate);
    // Integration
    this.add(integrationCreate_1.IntegrationCreate);
    // Invite
    this.add(inviteCreate_1.InviteCreate);
    this.add(inviteDelete_1.InviteDelete);
  }
  add(event) {
    const name = (0, index_1.camelCase)(event.name);
    if (this.gatewayShard.client.options.gateway.disabledEvents?.includes(name))
      return;
    this.events.set(name, new event(this.gatewayShard));
  }
  get(name) {
    const event = this.events.get(name);
    return event?.run.bind(event);
  }
  setGatewayShard(shard) {
    this.gatewayShard = shard;
    this._init();
    return this;
  }
}
exports.EventSource = EventSource;
