"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Ready = void 0;
/* eslint-disable @typescript-eslint/no-unnecessary-condition */
const Constants_1 = require("../../../utils/Constants");
const User_1 = require("../../../resources/User");
const Event_1 = require("./Event");
const Application_1 = require("../../../resources/Application");
class Ready extends Event_1.Event {
  async run(data) {
    this.gatewayShard.pendingGuilds += data.guilds.length;
    this.client.user = new User_1.ClientUser({
      ...data.user,
      client: this.client,
    });
    for (const unavailableGuild of data.guilds) {
      this.gatewayShard.pendingGuildsMap.set(
        unavailableGuild.id,
        unavailableGuild,
      );
    }
    this.gatewayShard.uptime = Date.now();
    this.gatewayShard.sessionId = data.session_id;
    this.gatewayShard.status = Constants_1.GatewayStatus.WaitingGuilds;
    this.gatewayShard.resumeURL = `${data.resume_gateway_url}?v=10&encoding=${this.gatewayShard.options.encoding}`;
    if (this.gatewayShard.options.compress) {
      this.gatewayShard.resumeURL += "&compress=lib-stream";
    }
    // Ready heartbeat
    this.gatewayShard.heartbeatAck = true;
    this.gatewayShard.sendHeartbeat();
    if (!this.client.applicationId) {
      this.gatewayShard.client.applicationId = data.application.id;
    }
    if (!this.client.applicationFlags) {
      this.client.applicationFlags = data.application.flags;
    }
    if (!this.client.application) {
      const rawApplication = await this.client.rest.getCurrentApplication();
      this.client.application = new Application_1.ClientApplication({
        ...rawApplication,
        client: this.client,
      });
    }
    this.client.cache.users.add(this.client.user);
    for (const guild of data.guilds) {
      this.gatewayShard.pendingGuildsMap.set(guild.id, guild);
    }
    this.gatewayShard.emit(Constants_1.ShardEvents.Ready);
    this.client.websocket.fireClientReady();
  }
}
exports.Ready = Ready;
