"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VoiceStateUpdate = void 0;
const VoiceState_1 = require("../../../resources/VoiceState");
const Member_1 = require("../../../resources/Member");
const Channel_1 = require("../../../resources/Channel");
const Event_1 = require("./Event");
const index_1 = require("../../../utils/index");
const index_2 = require("../../../utils/index");
const Constants_1 = require("../../../utils/Constants");
class VoiceStateUpdate extends Event_1.Event {
  run(data) {
    const guild = this.getGuild(data.guild_id);
    if (!guild) return;
    const oldVoiceState = (0, index_2.structuredClone)(
      guild.voiceStates.get(data.user_id),
    );
    const updated = new VoiceState_1.VoiceState(
      {
        ...data,
        client: this.client,
      },
      guild,
    );
    let member = guild.members.cache.get(data.user_id);
    if (!member && data.member?.user && data.member.joined_at) {
      member = guild.members.add(new Member_1.Member(data.member, guild));
    }
    const disabledEvents = this.client.options.gateway.disabledEvents;
    if (oldVoiceState?.channelId !== data.channel_id) {
      const channel = this.client.channels.cache.get(data.channel_id);
      const oldChannel = this.client.channels.cache.get(
        oldVoiceState?.channelId,
      );
      if (
        data.channel_id &&
        (channel instanceof Channel_1.VoiceChannel ||
          channel instanceof Channel_1.StageChannel)
      ) {
        guild.voiceStates.set(data.user_id, updated);
        if (
          oldVoiceState &&
          oldChannel &&
          !disabledEvents.includes("voiceChannelSwitch")
        ) {
          oldChannel.members.cache.delete(member.id);
          const m = channel.members.add(member);
          this.client.emit(
            Constants_1.Events.VoiceChannelSwitch,
            m,
            oldChannel,
            channel,
          );
        } else if (!disabledEvents.includes("voiceChannelJoin")) {
          const m = channel.members.add(member);
          this.client.emit(Constants_1.Events.VoiceChannelJoin, m, channel);
        }
      } else if (oldChannel && !disabledEvents.includes("voiceChannelLeave")) {
        oldChannel.members.cache.delete(member.id);
        guild.voiceStates.delete(data.user_id);
        this.client.emit(
          Constants_1.Events.VoiceChannelLeave,
          member,
          oldChannel,
        );
      }
    }
    if (
      (!oldVoiceState && updated) ||
      !(0, index_1.isEqual)(oldVoiceState, updated)
    ) {
      this.client.emit(Constants_1.Events.VoiceStateUpdate, member, updated);
    }
  }
}
exports.VoiceStateUpdate = VoiceStateUpdate;
