"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GuildChannelDataManager =
  exports.ClientChannelsDataManager =
  exports.ChannelDataManager =
    void 0;
const Channel_1 = require("../../resources/Channel");
const DataManager_1 = require("./DataManager");
const Resolvable_1 = require("../../utils/Resolvable");
class ChannelDataManager extends DataManager_1.DataManager {
  manager;
  constructor(options, manager) {
    super(options, (get, id) => {
      const channel = get(id);
      return channel && this._resolve(channel);
    });
    this.manager = manager;
  }
  _resolve(channel, guild, addInCache = false) {
    if (
      // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
      channel &&
      !(channel instanceof Channel_1.Channel)
    ) {
      if (channel?.guild_id && !guild) {
        guild = this.manager.client.guilds.cache.get(channel.guild_id);
      }
      channel = Channel_1.Channel.from(
        {
          ...channel,
          client: this.manager.client,
        },
        guild,
      );
      if (addInCache) this.add(channel);
    }
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    return channel;
  }
  add(channel, replace = true) {
    if (!channel || !channel.id) {
      return null;
    }
    return super.add(this._resolve(channel), replace, channel.id);
  }
  get(id) {
    return this.cache.get(id);
  }
  forge(id) {
    return this.add(
      new Channel_1.Channel({
        client: this.manager.client,
        id,
      }),
      false,
    );
  }
  async fetch(id) {
    const item = await this.manager.client.rest.getChannel(id);
    let guild;
    if ("guild_id" in item && item.guild_id) {
      guild = this.manager.client.guilds.cache.get(item.guild_id);
    }
    const i = Channel_1.Channel.from(
      {
        ...item,
        client: this.manager.client,
      },
      guild,
    );
    return this.add(i);
  }
}
exports.ChannelDataManager = ChannelDataManager;
class ClientChannelsDataManager extends ChannelDataManager {
  _add(channel, guild, replace = true) {
    return super.add(
      super._resolve(
        channel,
        guild
          ? Resolvable_1.Resolvable.resolveGuild(guild, this.manager.client)
          : undefined,
      ),
      replace,
    );
  }
}
exports.ClientChannelsDataManager = ClientChannelsDataManager;
class GuildChannelDataManager extends ChannelDataManager {
  guild;
  constructor(options, manager, guild) {
    super(options, manager);
    this.guild = guild;
  }
  add(channel, replace = true) {
    return super.add(super._resolve(channel, this.guild), replace);
  }
}
exports.GuildChannelDataManager = GuildChannelDataManager;
