"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DataManager = exports.DataCache = void 0;
const Cache_1 = require("../../cache/Cache");
class DataCache extends Cache_1.Cache {
  #resolver;
  _setResolver(resolver) {
    this.#resolver = resolver.bind(this);
  }
  get(key) {
    if (this.#resolver) {
      return this.#resolver((key_1) => super.get(key_1), key);
    }
    return super.get(key);
  }
  _add(item, replace = true, id) {
    if ("id" in item && !id) {
      id = item.id;
    }
    if (this.has(id) && !replace) {
      const existing = this.get(id);
      // If the item exists and is a structure with update function, update the existing value
      if (
        item &&
        typeof item === "object" &&
        item._update &&
        existing &&
        typeof existing === "object" &&
        existing._update
      ) {
        return existing._update("rawData" in item ? item.rawData : item);
      }
      return item;
    }
    this.set(id, item);
    return item;
  }
}
exports.DataCache = DataCache;
class DataManager {
  cache;
  constructor(limit, entries, resolver) {
    if (
      typeof entries === "function" &&
      !Array.isArray(entries) &&
      !(typeof limit === "object" && Symbol.iterator in limit)
    ) {
      resolver = entries;
      entries = undefined;
    }
    this.cache = new DataCache(limit, entries);
    if (typeof resolver === "function") {
      this.cache._setResolver(resolver);
    }
  }
  add(item, replace = true, id) {
    return this.cache._add(item, replace, id);
  }
}
exports.DataManager = DataManager;
