"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GuildEmojiDataManager = exports.EmojiDataManager = void 0;
const Emoji_1 = require("../../resources/Emoji");
const Constants_1 = require("../../utils/Constants");
const DataManager_1 = require("./DataManager");
class EmojiDataManager extends DataManager_1.DataManager {
  manager;
  constructor(options, manager) {
    super(options, (get, id) => {
      const emoji = get(id);
      return emoji && this.#resolve(emoji);
    });
    this.manager = manager;
  }
  get(id) {
    return this.cache.get(id);
  }
  #resolve(emoji, addInCache = false) {
    if (
      // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
      emoji &&
      !this.manager._partial(Constants_1.Partials.Emoji) &&
      !(emoji instanceof Emoji_1.Emoji)
    ) {
      emoji = new Emoji_1.Emoji(emoji);
      if (addInCache) this.add(emoji);
    }
    return emoji;
  }
  add(emoji, replace = true) {
    return super.add(this.#resolve(emoji), replace, emoji.id || emoji.name);
  }
  /**
   *
   * @param id emoji id
   * @param guild Guild object or Guild Id
   */
  async fetch(id, guild) {
    const emoji = await this.manager.client.rest.getEmoji(
      typeof guild === "string" ? guild : guild.id,
      id,
    );
    return this.add(emoji);
  }
}
exports.EmojiDataManager = EmojiDataManager;
class GuildEmojiDataManager extends EmojiDataManager {
  manager;
  guild;
  constructor(options, manager, guild) {
    super(options, manager);
    this.manager = manager;
    this.guild = guild;
  }
  fetch(id) {
    return super.fetch(id, this.guild);
  }
}
exports.GuildEmojiDataManager = GuildEmojiDataManager;
