"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoleDataManager = exports.ClientRoles = void 0;
const Guild_1 = require("../../resources/Guild");
const Role_1 = require("../../resources/Role");
const Constants_1 = require("../../utils/Constants");
const DataManager_1 = require("./DataManager");
class ClientRoles {
  cache;
  constructor(options) {
    this.cache = new DataManager_1.DataCache(options);
  }
}
exports.ClientRoles = ClientRoles;
class RoleDataManager extends DataManager_1.DataManager {
  manager;
  guild;
  constructor(options, manager, guild) {
    super(options, (get, id) => {
      const role = get(id);
      return role && this._resolve(role, true);
    });
    this.manager = manager;
    this.guild = guild;
  }
  get(id) {
    return this.cache.get(id);
  }
  add(role, replace = true) {
    if (!role || !role.id) {
      return null;
    }
    return super.add(this._resolve(role), replace, role.id);
  }
  forge(id) {
    return this.add(
      new Role_1.Role({ client: this.manager.client, id }, this.guild),
      false,
    );
  }
  _resolve(role, addInCache = false) {
    if (
      // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
      role &&
      !this.manager._partial(Constants_1.Partials.Role) &&
      !(role instanceof Role_1.Role)
    ) {
      role = new Role_1.Role(
        { ...role, client: this.manager.client },
        this.guild,
      );
      if (addInCache) this.add(role);
    }
    return role;
  }
  /**
   *
   * @param id role id
   * @param guild Guild object or Guild Id
   */
  async fetch(id, guild) {
    const existing = this.cache.get(id);
    if (existing) {
      return existing;
    }
    const rolesArr = await this.manager.client.rest.getRoles(
      typeof guild === "string" ? guild : guild.id,
    );
    const resolvedRolesArr = Promise.all(
      rolesArr.map(async (role) => {
        if (!this.manager._partial(Constants_1.Partials.Role)) {
          if (!(guild instanceof Guild_1.Guild)) {
            guild = this.manager.guilds.cache.get(
              typeof guild === "string" ? guild : guild.id,
            );
          }
          return this.add(
            new Role_1.Role(
              {
                ...role,
                client: this.manager.client,
              },
              guild,
            ),
          );
        }
        return this.add(role);
      }),
    );
    return (await resolvedRolesArr).find((role) => role?.id === id);
  }
}
exports.RoleDataManager = RoleDataManager;
