"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GuildStickerDataManager = exports.StickerDataManager = void 0;
const Sticker_1 = require("../../resources/Sticker");
const Constants_1 = require("../../utils/Constants");
const DataManager_1 = require("./DataManager");
class StickerDataManager extends DataManager_1.DataManager {
  manager;
  constructor(options, manager) {
    super(options, (get, id) => {
      const sticker = get(id);
      return sticker && this.#resolve(sticker, true);
    });
    this.manager = manager;
  }
  get(id) {
    return this.cache.get(id);
  }
  add(sticker, replace = true) {
    return super.add(this.#resolve(sticker), replace, sticker.id);
  }
  #resolve(sticker, addInCache = false) {
    if (
      !this.manager._partial(Constants_1.Partials.Sticker) &&
      !(sticker instanceof Sticker_1.Sticker)
    ) {
      sticker = new Sticker_1.Sticker({
        ...sticker,
        client: this.manager.client,
      });
      if (addInCache) this.add(sticker);
    }
    return sticker;
  }
  /**
   *
   * @param id sticker id
   * @param guild Guild object or Guild Id
   */
  async _fetch(id, guild, addInCache = true) {
    const sticker = await this.manager.client.rest.getGuildSticker(
      typeof guild === "string" ? guild : guild.id,
      id,
    );
    if (addInCache) {
      return this.add(sticker);
    }
    return sticker;
  }
}
exports.StickerDataManager = StickerDataManager;
class GuildStickerDataManager extends StickerDataManager {
  manager;
  guild;
  constructor(options, manager, guild) {
    super(options, manager);
    this.manager = manager;
    this.guild = guild;
  }
  fetch(id, addInCache = true) {
    return super._fetch(id, this.guild, addInCache);
  }
}
exports.GuildStickerDataManager = GuildStickerDataManager;
