"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserDataManager = void 0;
const User_1 = require("../../resources/User");
const Constants_1 = require("../../utils/Constants");
const DataManager_1 = require("./DataManager");
class UserDataManager extends DataManager_1.DataManager {
  manager;
  constructor(options, manager) {
    super(options);
    this.manager = manager;
  }
  get(id) {
    const user = this.cache.get(id);
    return user && this.#resolve(user, true);
  }
  forge(id) {
    return this.add(
      new User_1.User({
        client: this.manager.client,
        id,
      }),
      false,
    );
  }
  add(user, replace = true) {
    if (!user || !user.id) {
      return null;
    }
    return super.add(this.#resolve(user), replace, user.id);
  }
  #resolve(user, addInCache = false) {
    if (
      // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
      user &&
      !this.manager._partial(Constants_1.Partials.User) &&
      !(user instanceof User_1.User)
    ) {
      user = new User_1.User({ ...user, client: this.manager.client });
      if (addInCache) this.add(user);
    }
    return user;
  }
  async fetch(id) {
    let user = await this.manager.client.rest.getUser(id);
    return this.add(user);
  }
}
exports.UserDataManager = UserDataManager;
