"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Reaction = exports.Emoji = void 0;
const UserDataManager_1 = require("../../manager/UserDataManager");
const v10_1 = require("discord-api-types/v10");
const Base_1 = require("./Base");
class Emoji {
  /**
   * Whether this emoji must be wrapped in colons
   */
  requireColons;
  /**
   * Whether this emoji is managed
   */
  managed;
  /**
   * Whether this emoji can be used, may be false due to loss of Server Boosts
   */
  available;
  /**
   * Emoji name (can be null only in reaction emoji objects)
   */
  name;
  /**
   * Whether this emoji is animated
   */
  animated;
  /**
   * Emoji id
   */
  id;
  rawData;
  constructor(data) {
    this.id = data.id;
    this.requireColons = data.require_colons;
    this.managed = data.managed;
    this.available = data.available;
    this.name = data.name;
    this.animated = Boolean(data.animated);
    this.rawData = data;
  }
  createdAt() {
    return this.id && Base_1.Snowflake.getCreatedAt(this.id);
  }
  /**
   * Emoji url
   */
  get url() {
    return (
      this.id &&
      v10_1.RouteBases.cdn +
        v10_1.CDNRoutes.emoji(
          this.id,
          this.animated ? v10_1.ImageFormat.GIF : v10_1.ImageFormat.PNG,
        )
    );
  }
  get uriComponent() {
    return this.id
      ? `${this.animated ? "a:" : ""}${this.name}:${this.id}`
      : encodeURIComponent(this.name);
  }
  toString() {
    return this.id
      ? `<${this.animated ? "a" : ""}:${this.name}:${this.id}>`
      : this.name;
  }
  static from(emoji) {
    const r = Emoji.parse(emoji);
    return r && new Emoji(r);
  }
  static parse(emoji) {
    if (emoji === encodeURIComponent(emoji)) emoji = decodeURIComponent(emoji);
    if (!emoji.includes(":")) return null;
    const r = emoji.match(/<?(?:(a):)?(\w{2,32}):(\d{17,19})?>?/);
    return (
      r && {
        name: r[2],
        id: r[3],
        animated: Boolean(r[1]),
      }
    );
  }
  static getEncodedURI(emoji) {
    if (typeof emoji === "string") {
      emoji = Emoji.parse(emoji);
    }
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
    return emoji && emoji.id
      ? `${emoji.animated ? "a:" : ""}${emoji.name}:${emoji.id}`
      : encodeURIComponent(emoji.name);
  }
}
exports.Emoji = Emoji;
class Reaction {
  /**
   * Whether the current user reacted using this emoji
   */
  me;
  /**
   * Emoji information
   */
  emoji;
  /**
   * Times this emoji has been used to react
   */
  count;
  /**
   * Users reacted
   */
  users;
  client;
  constructor(data) {
    this.me = data.me;
    this.emoji = new Emoji(data.emoji);
    this.count = data.count;
    this.users = new UserDataManager_1.UserDataManager(
      data.client.cache._cacheLimit("users"),
      data.client.cache,
    );
    this.client = data.client;
  }
}
exports.Reaction = Reaction;
