"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Integration = void 0;
const Base_1 = require("./Base");
class Integration extends Base_1.Base {
  /**
   * Integration account information
   */
  account;
  /**
   * The bot/OAuth2 application for discord integrations
   */
  application;
  /**
   * Is this integration enabled
   */
  enabled;
  /**
   * The behavior of expiring subscribers
   */
  expireBehavior;
  /**
   * Whether emoticons should be synced for this integration (twitch only currently)
   */
  enableEmoticons;
  /**
   * The grace period (in days) before expiring subscribers
   */
  expireGracePeriod;
  /**
   * Integration name
   */
  name;
  /**
   * Has this integration been revoked
   */
  revoked;
  /**
   * ID that this integration uses for "subscribers"
   */
  roleId;
  /**
   * The scopes the application has been authorized for
   */
  scopes;
  /**
   * How many subscribers this integration has
   */
  subscriberCount;
  /**
   * When this integration was last synced
   */
  syncedAt;
  /**
   * Integration type
   */
  type;
  /**
   * User for this integration
   */
  user;
  /**
   * The integration guild
   */
  guild;
  constructor(data, guild) {
    super(data, guild._client);
    this.account = data.account;
    this.application = data.application;
    this.enabled = Boolean(data.enabled);
    this.expireBehavior = data.expire_behavior;
    this.enableEmoticons = Boolean(data.enable_emoticons);
    this.expireGracePeriod = data.expire_grace_period;
    this.name = data.name;
    this.revoked = Boolean(data.revoked);
    this.roleId = data.role_id;
    this.scopes = data.scopes;
    this.subscriberCount = data.subscriber_count;
    this.syncedAt = data.synced_at ? Date.parse(data.synced_at) : null;
    this.type = data.type;
    this.user = data.user ? this._client.cache.users.add(data.user) : null;
    this.guild = guild;
  }
  delete(reason) {
    return this._client.rest.deleteGuildIntegration(
      this.guild.id,
      this.id,
      reason,
    );
  }
}
exports.Integration = Integration;
