"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Role = void 0;
const Constants_1 = require("../../utils/Constants");
const Base_1 = require("./Base");
const Permission_1 = require("./Permission");
class Role extends Base_1.Base {
  guild;
  /**
   * Role name
   */
  name;
  /**
   * Integer representation of hexadecimal color code
   */
  color;
  /**
   * If this role is pinned in the user listing
   */
  hoist;
  /**
   * Role icon hash
   */
  icon;
  /**
   * Role unicode emoji
   */
  unicodeEmoji;
  /**
   * Position of this role
   */
  position;
  /**
   * Permission bit set
   */
  permissions;
  /**
   * Whether this role is managed by an integration
   */
  managed;
  /**
   * Whether this role is mentionable
   */
  mentionable;
  /**
   * The tags this role has
   */
  tags;
  constructor(data, guild) {
    super(data);
    this.guild = guild;
    this._update(data);
  }
  _update(data) {
    this.name = data.name;
    this.color = data.color;
    this.hoist = Boolean(data.hoist);
    this.icon = data.icon;
    this.position = data.position;
    this.mentionable = Boolean(data.mentionable);
    this.tags = data.tags;
    this.permissions = new Permission_1.Permissions(BigInt(data.permissions));
    this.managed = Boolean(data.managed);
    this.unicodeEmoji = data.unicode_emoji;
    return this;
  }
  setPosition(newPosition, reason) {
    return this.guild.setRolePosition(this.id, newPosition, reason);
  }
  edit(options, reason) {
    return this.guild.editRole(this.id, options, reason);
  }
  get forged() {
    return Boolean(this.id && !this.color && !this.name);
  }
  toString() {
    return (0, Constants_1.roleMention)(this.id);
  }
  toJSON() {
    return Base_1.Base.toJSON(this, [
      "color",
      "createdAt",
      "guild",
      "hoist",
      "icon",
      "id",
      "managed",
      "mentionable",
      "name",
      "permissions",
      "position",
      "rawData",
      "tags",
      "unicodeEmoji",
    ]);
  }
}
exports.Role = Role;
