"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VoiceState = void 0;
const Base_1 = require("./Base");
class VoiceState extends Base_1.Base {
  /**
   * The guild of voice state is for
   */
  guild;
  /**
   * The user id this voice state is for
   */
  userId;
  /**
   * The channel id this user is connected to
   */
  channelId;
  /**
   * Whether this user is deafened by the server
   */
  deaf;
  /**
   * The guild member this voice state is for
   */
  member;
  /**
   * Whether this user is muted by the server
   */
  mute;
  /**
   * The time at which the user requested to speak
   */
  requestToSpeakTimestamp;
  /**
   * Whether this user is locally deafened
   */
  selfDeaf;
  /**
   * Whether this user is locally muted
   */
  selfMute;
  /**
   * Whether this user is streaming using "Go Live"
   */
  selfStream;
  /**
   * Whether this user's camera is enabled
   */
  selfVideo;
  /**
   * The session id for this voice state
   */
  sessionId;
  /**
   * The guild id this voice state is for
   */
  guildId;
  /**
   * Whether this user is muted by the current user
   */
  suppress;
  constructor(data, guild) {
    super(data, data.client, data.user_id);
    this.guild = guild;
    this.userId = data.user_id;
    this.channelId = data.channel_id;
    this.deaf = data.deaf;
    this.member = data.member
      ? guild.members.cache.get(data.user_id) ?? null
      : null;
    this.mute = data.mute;
    this.requestToSpeakTimestamp = data.request_to_speak_timestamp
      ? Date.parse(data.request_to_speak_timestamp)
      : null;
    this.selfDeaf = data.self_deaf;
    this.selfMute = data.self_mute;
    this.selfStream = Boolean(data.self_stream);
    this.selfVideo = data.self_video;
    this.sessionId = data.session_id;
    this.guildId = data.guild_id;
    this.suppress = data.suppress;
  }
  /**
   * Disconnects the member from the voice channel
   * @param reason
   * @returns
   */
  disconnect(reason) {
    return this.moveMemberTo(null, reason);
  }
  /**
   * Move the member to another voice channel
   * @param channelId
   * @param reason
   * @returns
   */
  moveMemberTo(channelId, reason) {
    return this.member?.edit({ channelId }, reason);
  }
  edit(options) {
    return this._client.rest.modifyGuildVoiceState(
      this.guildId,
      this.userId === this._client.user?.id ? "@me" : this.userId,
      {
        channel_id: options.channelId,
        request_to_speak_timestamp: options.requestToSpeakTimestamp,
        suppress: options.suppress,
      },
    );
  }
}
exports.VoiceState = VoiceState;
