"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Webhook = void 0;
const rest_1 = require("@darkcord/rest");
const Base_1 = require("./Base");
class Webhook extends Base_1.Base {
  /**
   * The type of the webhook
   */
  type;
  /**
   * The guild id this webhook is for, if any
   */
  guildId;
  /**
   * The channel id this webhook is for, if any
   */
  channelId;
  /**
   * The user this webhook was created by (not returned when getting a webhook with its token)
   */
  user;
  /**
   * The default name of the webhook
   */
  name;
  /**
   * The default user avatar hash of the webhook
   */
  avatar;
  /**
   * The secure token of the webhook (returned for Incoming Webhooks)
   */
  token;
  /**
   * The bot/OAuth2 application that created this webhook
   */
  applicationId;
  /**
   * The guild of the channel that this webhook is following (returned for Channel Follower Webhooks)
   */
  sourceGuild;
  /**
   * The channel that this webhook is following (returned for Channel Follower Webhooks)
   */
  sourceChannel;
  /**
   * The url used for executing the webhook (returned by the webhooks OAuth2 flow)
   */
  url;
  /**
   * Rest to make requests
   */
  rest;
  constructor(data) {
    super(data, data.client);
    this.type = data.type;
    this.guildId = data.guild_id;
    this.user = data.user ? this._client.users.add(data.user) : null;
    this.token = data.token;
    this.applicationId = data.application_id;
    this._update(data);
    this.rest = new rest_1.Rest(this.token);
  }
  sendMessage(data) {
    if (!this.token) return Promise.resolve();
    return this.rest.executeWebhook(this.id, this.token, data);
  }
  delete() {
    if (!this.token) return Promise.resolve();
    return this.rest.deleteWebhookWithToken(this.id, this.token);
  }
  async edit(options) {
    if (!this.token) return Promise.resolve();
    const updated = await this.rest.modifyWebhookWithToken(
      this.id,
      this.token,
      {
        avatar: options.avatar,
        channel_id: options.channelId,
        name: options.name,
      },
    );
    return this._update(updated);
  }
  _update(data) {
    if ("name" in data) this.name = data.name;
    if ("avatar" in data) this.avatar = data.avatar;
    if ("channel_id" in data) this.channelId = data.channel_id;
    if ("url" in data) this.url = data.url;
    if ("source_guild" in data && data.source_guild) {
      this.sourceGuild =
        this._client.guilds.cache.get(data.source_guild.id) ??
        data.source_guild;
    }
    if ("source_channel" in data && data.source_channel) {
      this.sourceChannel =
        this._client.channels.cache.get(data.source_channel.id) ??
        data.source_channel;
    }
    return this;
  }
}
exports.Webhook = Webhook;
