import { DataWithClient } from "../types/index";
import { APIApplication, APIApplicationInstallParams, APIUser, ApplicationFlags, RESTPatchAPIApplicationCommandJSONBody, RESTPostAPIApplicationCommandsJSONBody, RESTPutAPIApplicationCommandsJSONBody } from "discord-api-types/v10";
import { Base } from "./Base";
import { Team } from "./Team";
import { User } from "./User";
export declare class Application extends Base {
    /**
     * The name of the app
     */
    name: string;
    /**
     * The icon hash of the app
     */
    icon: string | null;
    /**
     * The description of the app
     */
    description: string;
    /**
     * An array of rpc origin urls, if rpc is enabled
     */
    rpcOrigins?: string[] | undefined;
    /**
     * When false only app owner can join the app's bot to guilds
     */
    botPublic: boolean;
    /**
     * When true the app's bot will only join upon completion of the full oauth2 code grant flow
     */
    botRequireCodeGrant: boolean;
    /**
     * The url of the app's terms of service
     */
    termsOfServiceUrl?: string | undefined;
    /**
     * The url of the app's privacy policy
     */
    privacyPolicyUrl?: string | undefined;
    /**
     * Partial user object containing info on the owner of the application
     */
    owner?: User | APIUser | null;
    /**
     * The hex encoded key for verification in interactions and the GameSDK's GetTicket
     */
    verifyKey: string;
    /**
     * If the application belongs to a team, this will be a list of the members of that team
     */
    team: Team | null;
    /**
     * If this application is a game sold on Discord, this field will be the guild to which it has been linked
     */
    guildId?: string | undefined;
    /**
     * If this application is a game sold on Discord, this field will be the id of the "Game SKU" that is created, if exists
     */
    primarySkuId?: string | undefined;
    /**
     * If this application is a game sold on Discord, this field will be the URL slug that links to the store page
     */
    slug?: string | undefined;
    /**
     * The application's default rich presence invite cover image hash
     */
    coverImage?: string | undefined;
    /**
     * The application's public flags
     */
    flags: ApplicationFlags;
    /**
     * Up to 5 tags describing the content and functionality of the application
     */
    tags?: [
        string,
        (string | undefined)?,
        (string | undefined)?,
        (string | undefined)?,
        (string | undefined)?
    ] | undefined;
    /**
     * Settings for the application's default in-app authorization link, if enabled
     */
    installParams?: APIApplicationInstallParams | undefined;
    /**
     * The application's default custom authorization link, if enabled
     */
    customInstallUrl?: string | undefined;
    /**
     * The application's role connection verification entry point, which when configured will render the app as a verification method in the guild role verification configuration
     */
    roleConnectionsVerificationUrl?: string | undefined;
    constructor(data: DataWithClient<APIApplication>);
}
export declare class ClientApplication extends Application {
    createCommand(options: RESTPostAPIApplicationCommandsJSONBody): Promise<import("discord-api-types/v10").APIApplicationCommand>;
    createGuildCommand(guildId: string, options: RESTPostAPIApplicationCommandsJSONBody): Promise<import("discord-api-types/v10").APIApplicationCommand>;
    deleteCommand(commandId: string): Promise<void>;
    deleteGuildCommand(guildId: string, commandId: string): Promise<void>;
    editCommand(commandId: string, options: RESTPatchAPIApplicationCommandJSONBody): Promise<import("discord-api-types/v10").APIApplication>;
    editGuildCommand(guildId: string, commandId: string, options: RESTPatchAPIApplicationCommandJSONBody): Promise<import("discord-api-types/v10").APIApplication>;
    bulkOverwriteCommands(commands: RESTPutAPIApplicationCommandsJSONBody): Promise<import("discord-api-types/v10").APIApplication[]>;
    bulkOverwriteGuildCommands(guildId: string, commands: RESTPutAPIApplicationCommandsJSONBody): Promise<import("discord-api-types/v10").APIApplication[]>;
}
//# sourceMappingURL=Application.d.ts.map