import { APIGuildIntegration, APIGuildIntegrationApplication, APIGuildIntegrationType, APIIntegrationAccount, APIUser, IntegrationExpireBehavior, OAuth2Scopes } from "discord-api-types/v10";
import { Base } from "./Base";
import { Guild } from "./Guild";
import { User } from "./User";
export declare class Integration extends Base {
    /**
     * Integration account information
     */
    account: APIIntegrationAccount;
    /**
     * The bot/OAuth2 application for discord integrations
     */
    application: APIGuildIntegrationApplication;
    /**
     * Is this integration enabled
     */
    enabled: boolean;
    /**
     * The behavior of expiring subscribers
     */
    expireBehavior: IntegrationExpireBehavior;
    /**
     * Whether emoticons should be synced for this integration (twitch only currently)
     */
    enableEmoticons: boolean;
    /**
     * The grace period (in days) before expiring subscribers
     */
    expireGracePeriod: number;
    /**
     * Integration name
     */
    name: string;
    /**
     * Has this integration been revoked
     */
    revoked: boolean;
    /**
     * ID that this integration uses for "subscribers"
     */
    roleId: string;
    /**
     * The scopes the application has been authorized for
     */
    scopes: OAuth2Scopes[];
    /**
     * How many subscribers this integration has
     */
    subscriberCount: number;
    /**
     * When this integration was last synced
     */
    syncedAt: number | null;
    /**
     * Integration type
     */
    type: APIGuildIntegrationType;
    /**
     * User for this integration
     */
    user: User | APIUser | null;
    /**
     * The integration guild
     */
    guild: Guild;
    constructor(data: APIGuildIntegration, guild: Guild);
    delete(reason?: string): Promise<void>;
}
//# sourceMappingURL=Integration.d.ts.map