import { DataWithClient, KeysToCamelCase } from "../types/index";
import type { APIRole, APIRoleTags, RESTPatchAPIGuildRoleJSONBody } from "discord-api-types/v10";
import { Base } from "./Base";
import { Guild } from "./Guild";
import { Permissions } from "./Permission";
export declare class Role extends Base {
    guild: Guild;
    /**
     * Role name
     */
    name: string;
    /**
     * Integer representation of hexadecimal color code
     */
    color: number;
    /**
     * If this role is pinned in the user listing
     */
    hoist: boolean;
    /**
     * Role icon hash
     */
    icon?: string | null;
    /**
     * Role unicode emoji
     */
    unicodeEmoji?: string | null;
    /**
     * Position of this role
     */
    position: number;
    /**
     * Permission bit set
     */
    permissions: Permissions;
    /**
     * Whether this role is managed by an integration
     */
    managed: boolean;
    /**
     * Whether this role is mentionable
     */
    mentionable: boolean;
    /**
     * The tags this role has
     */
    tags?: APIRoleTags;
    constructor(data: DataWithClient<APIRole>, guild: Guild);
    _update(data: APIRole): this;
    /**
     * Compare the position of the current role with another role
     * @param roleId The role id to compare with
     * @returns
     */
    comparePositionTo(roleId: string): number;
    /**
     * Modify the position of this role
     * @param newPosition The new position of the role
     * @param reason The reason for modifying the position
     * @returns
     */
    setPosition(newPosition: number, reason?: string): Promise<Role>;
    /**
     * Edit this role
     * @param options The options to edit this role
     * @param reason The reason for editing this role
     * @returns
     */
    edit(options: KeysToCamelCase<RESTPatchAPIGuildRoleJSONBody>, reason?: string): Promise<Role>;
    /**
     * Update information of this role
     *
     * Util if this is forged
     * @returns
     */
    fetchInformation(): Promise<this>;
    get forged(): boolean;
    toString(): `<@&${string}>`;
    toJSON(): {
        readonly createdAt: number;
        id: string;
        rawData: Record<string, any> & {
            id?: string | undefined;
        };
        name: string;
        position: number;
        color: number;
        hoist: boolean;
        icon?: string | null | undefined;
        mentionable: boolean;
        tags?: APIRoleTags | undefined;
        permissions: Permissions;
        managed: boolean;
        guild: Guild;
        unicodeEmoji?: string | null | undefined;
    };
}
//# sourceMappingURL=Role.d.ts.map