import { DataWithClient, DisplayUserAvatarOptions, DisplayUserBannerOptions, ImageSize, JSONClientUserPatch } from "../types/index";
import { APIDMChannel, APIUser, LocaleString, UserFlags, UserPremiumType } from "discord-api-types/v10";
import { Base } from "./Base";
import { DMChannel } from "./Channel";
export declare class User extends Base {
    /**
     * The user's id
     */
    id: string;
    /**
     * The user's username, not unique across the platform
     */
    username: string;
    /**
     * The user's 4-digit discord-tag
     */
    discriminator: string;
    /**
     * The user's avatar hash
     */
    avatar: string | null;
    /**
     * Whether the user belongs to an OAuth2 application
     */
    bot?: boolean;
    /**
     * Whether the user is an Official Discord System user (part of the urgent message system)
     */
    system?: boolean;
    /**
     * Whether the user has two factor enabled on their account
     */
    mfaEnabled?: boolean;
    /**
     * The user's banner hash
     */
    banner?: string | null;
    /**
     * The user's banner color encoded as an integer representation of hexadecimal color code
     */
    accentColor: number | null;
    /**
     * The user's chosen language option
     */
    locale?: LocaleString;
    /**
     * Whether the email on this account has been verified
     */
    verified: boolean;
    /**
     * The flags on a user's account
     */
    flags: UserFlags | null;
    /**
     * The type of Nitro subscription on a user's account
     */
    premiumType?: UserPremiumType;
    /**
     * The public flags on a user's account
     */
    publicFlags: UserFlags | null;
    /**
     * The user's display name, if it is set. For bots, this is the application name
     */
    globalName: string | null;
    /**
     * The user's avatar decoration hash
     */
    avatarDecoration: string | null | undefined;
    constructor(data: DataWithClient<APIUser>);
    _update(data: APIUser & {
        avatar_decoration_data?: {
            asset: string;
            sku_id: string;
        };
    }): this;
    /**
     * The user's avatar decoration url
     * @param options options for avatar decoration url
     * @returns
     */
    avatarDecorationURL(options?: ImageSize): string | null;
    /**
     * The default user's avatar url
     * @returns
     */
    get defaultAvatarURL(): string;
    /**
     * The user's banner url
     * @param options options for banner url
     * @returns
     */
    bannerURL(options?: DisplayUserBannerOptions): string | null;
    /**
     * The user's avatar url
     * @param options options for avatar url
     * @returns
     */
    avatarURL(options?: DisplayUserAvatarOptions): string | null;
    /**
     * The user's display avatar url
     * @param options options for display avatar url
     * @returns
     */
    displayAvatarURL(options?: DisplayUserAvatarOptions): string;
    /**
     * The user's display name
     * @returns
     */
    displayName(): string;
    /**
     * The user's username and discriminator
     */
    get tag(): string;
    /**
     * The dm of user
     */
    get dm(): DMChannel | null;
    /**
     * Create a new DM channel for this user
     */
    createDM(): Promise<DMChannel | APIDMChannel>;
    /**
     * Delete this user dm if existing one
     */
    deleteDM(): Promise<void>;
    get forged(): boolean;
    /**
     * Update information of this user
     *
     * Util if this is forged
     * @returns
     */
    fetchInformation(): Promise<this>;
    toString(): `<@${string}>`;
    toJSON(): {
        readonly createdAt: number;
        id: string;
        rawData: Record<string, any> & {
            id?: string | undefined;
        };
        username: string;
        discriminator: string;
        avatar: string | null;
        bot?: boolean | undefined;
        system?: boolean | undefined;
        banner?: string | null | undefined;
        locale?: "id" | "en-US" | "en-GB" | "bg" | "zh-CN" | "zh-TW" | "hr" | "cs" | "da" | "nl" | "fi" | "fr" | "de" | "el" | "hi" | "hu" | "it" | "ja" | "ko" | "lt" | "no" | "pl" | "pt-BR" | "ro" | "ru" | "es-ES" | "es-419" | "sv-SE" | "th" | "tr" | "uk" | "vi" | undefined;
        flags: UserFlags | null;
        accentColor: number | null;
        readonly defaultAvatarURL: string;
        readonly dm: DMChannel | null;
        readonly tag: string;
        publicFlags: UserFlags | null;
        premiumType?: UserPremiumType | undefined;
        mfaEnabled?: boolean | undefined;
    };
}
export declare class ClientUser extends User {
    edit(data: JSONClientUserPatch): Promise<void>;
}
//# sourceMappingURL=User.d.ts.map