import { DataWithClient, KeysToCamelCase } from "../types/index";
import { GatewayVoiceState, RESTPatchAPIGuildVoiceStateCurrentMemberJSONBody } from "discord-api-types/v10";
import { Base } from "./Base";
import { Guild } from "./Guild";
import { Member } from "./Member";
export declare class VoiceState extends Base {
    /**
     * The guild of voice state is for
     */
    guild: Guild;
    /**
     * The user id this voice state is for
     */
    userId: string;
    /**
     * The channel id this user is connected to
     */
    channelId: string | null;
    /**
     * Whether this user is deafened by the server
     */
    deaf: boolean;
    /**
     * The guild member this voice state is for
     */
    member: Member | null;
    /**
     * Whether this user is muted by the server
     */
    mute: boolean;
    /**
     * The time at which the user requested to speak
     */
    requestToSpeakTimestamp: number | null;
    /**
     * Whether this user is locally deafened
     */
    selfDeaf: boolean;
    /**
     * Whether this user is locally muted
     */
    selfMute: boolean;
    /**
     * Whether this user is streaming using "Go Live"
     */
    selfStream: boolean;
    /**
     * Whether this user's camera is enabled
     */
    selfVideo: boolean;
    /**
     * The session id for this voice state
     */
    sessionId: string;
    /**
     * The guild id this voice state is for
     */
    guildId: string;
    /**
     * Whether this user is muted by the current user
     */
    suppress: boolean;
    constructor(data: DataWithClient<GatewayVoiceState>, guild: Guild);
    /**
     * Disconnects the member from the voice channel
     * @param reason
     * @returns
     */
    disconnect(reason?: string): Promise<Member> | undefined;
    /**
     * Move the member to another voice channel
     * @param channelId
     * @param reason
     * @returns
     */
    moveMemberTo(channelId: string | null, reason?: string): Promise<Member> | undefined;
    edit(options: KeysToCamelCase<RESTPatchAPIGuildVoiceStateCurrentMemberJSONBody>): Promise<void>;
}
//# sourceMappingURL=VoiceState.d.ts.map