import { Rest } from "@darkcord/rest";
import { DataWithClient, KeysToCamelCase, MessagePostData } from "../types/index";
import { APIPartialChannel, APIPartialGuild, APIUser, APIWebhook, RESTPatchAPIWebhookJSONBody, WebhookType } from "discord-api-types/v10";
import { Base } from "./Base";
import { GuildChannel } from "./Channel";
import { Guild } from "./Guild";
import { User } from "./User";
export declare class Webhook extends Base {
    /**
     * The type of the webhook
     */
    type: WebhookType;
    /**
     * The guild id this webhook is for, if any
     */
    guildId?: string;
    /**
     * The channel id this webhook is for, if any
     */
    channelId: string;
    /**
     * The user this webhook was created by (not returned when getting a webhook with its token)
     */
    user?: User | APIUser | null;
    /**
     * The default name of the webhook
     */
    name: string | null;
    /**
     * The default user avatar hash of the webhook
     */
    avatar: string | null;
    /**
     * The secure token of the webhook (returned for Incoming Webhooks)
     */
    token?: string;
    /**
     * The bot/OAuth2 application that created this webhook
     */
    applicationId: string | null;
    /**
     * The guild of the channel that this webhook is following (returned for Channel Follower Webhooks)
     */
    sourceGuild?: Guild | APIPartialGuild;
    /**
     * The channel that this webhook is following (returned for Channel Follower Webhooks)
     */
    sourceChannel?: GuildChannel | APIPartialChannel;
    /**
     * The url used for executing the webhook (returned by the webhooks OAuth2 flow)
     */
    url?: string;
    /**
     * Rest to make requests
     */
    rest: Rest;
    constructor(data: DataWithClient<APIWebhook>);
    sendMessage(data: MessagePostData): Promise<void>;
    delete(): Promise<unknown>;
    edit(options: KeysToCamelCase<RESTPatchAPIWebhookJSONBody>): Promise<void | this>;
    _update(data: APIWebhook): this;
}
//# sourceMappingURL=Webhook.d.ts.map