import { Client } from "../client/Client";
import * as Application from "../resources/Application";
import * as AuditLog from "../resources/AuditLog";
import * as Base from "../resources/Base";
import * as BitField from "../resources/BitField";
import * as AnyChannel from "../resources/Channel";
import * as EmojiOrReaction from "../resources/Emoji";
import * as AnyGuild from "../resources/Guild";
import * as Integration from "../resources/Integration";
import * as AnyInteraction from "../resources/Interaction";
import * as Invite from "../resources/Invite";
import * as AnyMember from "../resources/Member";
import * as Message from "../resources/Message";
import * as Webhook from "../resources/Webhook";
export type AnyResource = typeof AnyChannel | typeof AnyGuild | typeof AnyInteraction | typeof Invite | typeof EmojiOrReaction | typeof Webhook | typeof Integration | typeof AnyMember | typeof Message | typeof BitField | typeof Base | typeof AuditLog | typeof Application;
export interface ResourceObject {
    baseFile: string;
    exports: AnyResource;
}
export interface PluginObject {
    name: string;
    version: string;
    load(): void;
    onStart(): void;
}
export type PluginFn = (manager: PluginManager) => PluginObject;
export declare class PluginManager {
    client: Client;
    resources: ResourceObject[];
    plugins: Map<string, PluginObject>;
    constructor(client: Client);
    addProperty<T>(key: string, value: T): T;
    emit(event: string, ...args: any[]): void;
    getResourcePack(resourceName: string): ResourceObject;
    getResourceInPack<T = any>(resourceName: string): T;
    /**
     * Extends a resource
     * @param resourceName resource to be extended
     * @param replacer replacer to extend resource
     */
    extends<T>(resourceName: string, replacer: (x: T) => any): void;
    /**
     *
     * @param resources resources names to be extended's
     * @param replacer replacer to extends resources
     */
    extendsMultiple<T>(resources: string[], replacer: (x: T) => any): void;
    /**
     *
     * @param path Path of file to be override
     * @param replacer replacer function to replace file
     */
    override<T>(path: string, replacer: (x: T) => any): void;
    load(pluginFn: PluginFn): void;
}
//# sourceMappingURL=PluginManager.d.ts.map